@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -179,6 +179,35 @@ def get_family_pattern(filelist):
         rootname = name1[0:]
     return rootname
 
+
+def _to_slice_mode(single_idx, shape):
+    assert len(shape) > 1
+    if len(shape) == 2:
+        return [single_idx]
+    reference = single_idx
+    slice_index = [None] * (len(shape) - 1)
+    for i in range(len(shape)-1):
+        v = 1
+        for j in range(i+1, len(shape)-1):
+            v *= shape[j]
+        slice_index[i] = reference // v
+        reference = reference % v
+    return slice_index
+
+
+def _to_index_mode(slice_idx, shape):
+    assert len(shape) > 1
+    assert len(slice_idx) == (len(shape) - 1)
+    if len(shape) == 2:
+        return slice_idx[0]
+    single_index = 0
+    for i in range(len(slice_idx)):
+        v = 1
+        for j in range(i+1, len(shape) - 1): 
+            v *= shape[j]
+        single_index += v * slice_idx[i]
+    return single_index
+
 class NexusDataSource(object):
     def __init__(self,nameInput):
         if type(nameInput) == type([]):
@@ -351,6 +380,27 @@ class NexusDataSource(object):
             _logger.warning(txt)
             output.info["title"] = ""
         output.info['selection'] = selection
+        if entry != "/":
+            try:
+                positioners = NexusTools.getPositionersGroup(phynxFile, entry)
+                if positioners is not None:
+                    output.info['MotorNames'] = []
+                    output.info['MotorValues'] = []
+                    for key in positioners.keys():
+                        if positioners[key].dtype in [object, numpy.object_]:
+                            # not a standard value
+                            _logger.info("Skipping object key %s" % key)
+                            continue
+                        output.info['MotorNames'].append(key)
+                        value = positioners[key][()]
+                        if hasattr(value, "size"):
+                            if value.size > 1:
+                                if hasattr(value, "flat"):
+                                    value = value.flat[0]
+                        output.info['MotorValues'].append(value)
+            except:
+                # I cannot affort to fail here for something probably not used
+                _logger.debug("Error reading positioners\n%s", sys.exc_info())
         if "mca" in selection:
             # this should go somewhere else
             h5File = phynxFile
@@ -421,6 +471,44 @@ class NexusDataSource(object):
                                     output.info["McaLiveTime"].sum()
                         if selection['mcaselectiontype'].lower() != "sum":
                             output.info["McaLiveTime"] /= divider
+                elif selection['mcaselectiontype'].lower().startswith("index") or \
+                     selection['mcaselectiontype'].lower().startswith("slice"):
+                    exp = re.compile(r'(-?[0-9]+\.?[0-9]*)')
+                    re_items = exp.findall(selection['mcaselectiontype'].lower())
+                    if selection['mcaselectiontype'].lower().startswith("index"):
+                        assert(len(re_items) == 1)
+                        single_idx = int(re_items[0])
+                        slice_idx = _to_slice_mode(single_idx, mcaData.shape)
+                    else:
+                        assert(len(re_items) == len(mcaData.shape) - 1)
+                        slice_idx = [int(re_item) for re_item in re_items]
+                        single_idx = _to_index_mode(slice_idx, mcaData.shape)
+                    # care for self consistency
+                    assert(_to_index_mode(slice_idx, mcaData.shape) == single_idx)
+
+                    if len(mcaData.shape) > 1:
+                        for idx in slice_idx:
+                            mcaData = mcaData[idx]
+                        mcaData = numpy.array(mcaData, dtype=numpy.float32)
+                    else:
+                        mcaData = mcaData[()]
+                    if "McaLiveTime" in output.info:
+                        if numpy.isscalar(output.info["McaLiveTime"]):
+                            # it is already a single number
+                            pass
+                        elif output.info["McaLiveTime"].shape == 1:
+                            if output.info["McaLiveTime"].shape[0] == 1:
+                                output.info["McaLiveTime"] = output.info["McaLiveTime"][0]
+                            else:
+                                output.info["McaLiveTime"] = output.info["McaLiveTime"][single_idx]
+                        else:
+                            # convert the single index to slice
+                            output.info["McaLiveTime"] = \
+                                    output.info["McaLiveTime"].flatten()[single_idx]
+                    if "MotorNames" in output.info:
+                       for idx in range(len(output.info["MotorNames"])):
+                           value = output.info["MotorValues"][idx]
+                           output.info['MotorValues'][idx] = value[single_idx]
             except:
                 # import traceback
                 _logger.error("%s", sys.exc_info())
@@ -445,33 +533,14 @@ class NexusDataSource(object):
             output.info['LabelNames'] = selection['aliaslist']
         else:
             output.info['LabelNames'] = selection['cntlist']
-        if entry != "/":
-            try:
-                positioners = NexusTools.getPositionersGroup(phynxFile, entry)
-                if positioners is not None:
-                    output.info['MotorNames'] = []
-                    output.info['MotorValues'] = []
-                    for key in positioners.keys():
-                        if positioners[key].dtype in [object, numpy.object_]:
-                            # not a standard value
-                            _logger.info("Skipping object key %s" % key)
-                            continue
-                        output.info['MotorNames'].append(key)
-                        value = positioners[key][()]
-                        if hasattr(value, "size"):
-                            if value.size > 1:
-                                if hasattr(value, "flat"):
-                                    value = value.flat[0]
-                        output.info['MotorValues'].append(value)
-            except:
-                # I cannot affort to fail here for something probably not used
-                _logger.debug("Error reading positioners\n%s", sys.exc_info())
         for cnt in ['y', 'x', 'm']:
             if not cnt in selection:
                 continue
             if not len(selection[cnt]):
                 continue
             path =  entry + selection['cntlist'][selection[cnt][0]]
+
+            # get the data
             data = phynxFile[path]
             totalElements = 1
             for dim in data.shape:
@@ -482,12 +551,48 @@ class NexusDataSource(object):
                 except MemoryError:
                     data = phynxFile[path]
                     pass
+
+            # get the selection if any
+            selectionTypeKey = cnt + "selectiontype"
+            if selection[selectionTypeKey][0].startswith("index") or \
+               selection[selectionTypeKey][0].startswith("slice"):
+                exp = re.compile(r'(-?[0-9]+\.?[0-9]*)')
+                re_items = exp.findall(selection[selectionTypeKey][0].lower())
+                if selection[selectionTypeKey][0].lower().startswith("index"):
+                    assert(len(re_items) == 1)
+                    single_idx = int(re_items[0])
+                    slice_idx = _to_slice_mode(single_idx, data.shape)
+                else:
+                    assert(len(re_items) == len(data.shape) - 1)
+                    slice_idx = [int(re_item) for re_item in re_items]
+                    single_idx = _to_index_mode(slice_idx, data.shape)
+                # care for self consistency
+                assert(_to_index_mode(slice_idx, data.shape) == single_idx)
+
+                if output.info['selectiontype'] in ["1D", "MCA"]:
+                    if len(data.shape) > 1:
+                        for idx in slice_idx:
+                            data = data[idx]
+                        data = numpy.array(data, dtype=numpy.float32)
+                    else:
+                        data = data[()]
+                else:
+                    data = data[single_idx]
+
             if output.info['selectiontype'] in ["1D", "MCA"]:
                 if (len(data.shape) > 1) and ('mcaselectiontype' in selection):
                     mcaselectiontype = selection['mcaselectiontype'].lower()
                     nSpectra = 1.0
                     for iDummy in data.shape[:-1]:
-                        data = data.sum(axis=0, dtype=numpy.float64)
+                        # we might be working with an HDF5 dataset here
+                        if hasattr(data, "sum"):
+                            data = data.sum(axis=0, dtype=numpy.float64)
+                        else:
+                            tmpSum = numpy.zeros(data.shape[1:], dtype=numpy.float64)
+                            for i in range(iDummy):
+                                tmpSum += data[i]
+                            data = tmpSum
+                            tmpSum = None
                         nSpectra *= iDummy
                     if mcaselectiontype == "sum":
                         # sum already calculated
@@ -496,6 +601,26 @@ class NexusDataSource(object):
                         # calculate the average
                         _logger.debug("AVERAGE")
                         data /= nSpectra
+                    elif selection['mcaselectiontype'].lower().startswith("index") or \
+                         selection['mcaselectiontype'].lower().startswith("slice"):
+                        exp = re.compile(r'(-?[0-9]+\.?[0-9]*)')
+                        re_items = exp.findall(selection['mcaselectiontype'].lower())
+                        if selection['mcaselectiontype'].lower().startswith("index"):
+                            assert(len(re_items) == 1)
+                            single_idx = int(re_items[0])
+                            slice_idx = _to_slice_mode(single_idx, data.shape)
+                        else:
+                            assert(len(re_items) == len(data.shape) - 1)
+                            slice_idx = [int(re_item) for re_item in re_items]
+                            single_idx = _to_index_mode(slice_idx, data.shape)
+                        # care for self consistency
+                        assert(_to_index_mode(slice_idx, data.shape) == single_idx)
+                        if len(data.shape) > 1:
+                            for idx in slice_idx:
+                                data = data[idx]
+                            data = numpy.array(mcaData, dtype=numpy.float32)
+                        else:
+                            data = mcaData[()]
                     else:
                         _logger.warning("Unsupported selection type %s",
                                         mcaselectiontype)
@@ -521,6 +646,8 @@ class NexusDataSource(object):
                 if output.x is None:
                     output.x = [data]
                 if len(selection[cnt]) > 1:
+                    # TODO: if the selection for the additional axes is not complete
+                    # this will not work.
                     for xidx in range(1, len(selection[cnt])):
                         path =  entry + selection['cntlist'][selection[cnt][xidx]]
                         data = phynxFile[path][()]
