@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2018-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2018-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -42,6 +42,7 @@ try:
 except:
     # but do not crash just because of it
     pass
+import h5py
 from h5py import File, Dataset, Group
 try:
     from silx.io import is_dataset, is_group
@@ -135,24 +136,39 @@ def _get_number_list(txt):
     nbs= [float(w) for w in re.split(rexpr, txt) if w not in ['',' ']]
     return nbs
 
-def getEntryName(path):
+def getEntryName(path, h5file=None):
     """
     Retrieve the top level name (not h5py object) associated to a given path
     despite being or not an NXentry group.
     """
-    entry = path
-    candidate = posixpath.dirname(entry)
+    entry_name = path
+    candidate = posixpath.dirname(entry_name)
     while len(candidate) > 1:
-        entry = candidate
-        candidate = posixpath.dirname(entry)
-    return entry
+        entry_name = candidate
+        candidate = posixpath.dirname(entry_name)
+    if h5file is not None:
+        if entry_name not in h5file["/"]:
+            # dealing with a external link?
+            items_list = list(h5file["/"].items())
+            for key, group in items_list:
+                if not isGroup(group):
+                    continue
+                if group.name == entry_name:
+                    link = h5file.get(key, getlink=True)
+                    if isinstance(link, h5py.ExternalLink):
+                        _logger.info("Dealing with external link")
+                        _logger.info("External filename = <%s>" % link.filename)
+                        _logger.info("External path = <%s>" % link.path)
+                        entry_name = "/" + key
+                        break
+    return entry_name
 
 def getTitle(h5file, path):
     """
     Retrieve the title associated to the entry asoociated to the provided path
     It returns an emptry string of not title is found
     """
-    entry = h5file[getEntryName(path)]
+    entry = h5file[getEntryName(path, h5file=h5file)]
     title = ''
     if isGroup(entry) and "title" in entry:
         title = entry["title"][()]
@@ -205,6 +221,29 @@ def getNXClassList(h5file, path, classes, objects=False):
         h5file[path].visititems(visit_function)
     return pathList
 
+def _correct_entry_path(path, entry_in, entry_out):
+    if entry_in in path:
+        if path.index(entry_in) == 0:
+            return entry_out + path[len(entry_in):]
+    return path
+
+def sanitizeFilePath(h5file, path, entry=None):
+    """
+    This deals with the ESRF case of having a top-level entry being an external link
+    to another top-level entry but with different name
+    """
+    try:
+        h5file[path]
+    except KeyError:
+        if entry is None:
+            # this can still fail 
+            # the case where it fails is when two external links point to two different
+            # files with the same entry name. Easily found at ESRF with top level master
+            path = _correct_entry_path(path, getEntryName(path), getEntryName(path, h5file))
+        else:
+            path = _correct_entry_path(path, getEntryName(path), entry)
+    return path
+
 def getMcaList(h5file, path, dataset=False, ignore=None):
     """
     Retrieve the hdf5 dataset names down a given path where the interpretation attribute
@@ -222,6 +261,20 @@ def getMcaList(h5file, path, dataset=False, ignore=None):
     and link to it named /entry/measurement/mca
 
     """
+    _logger.debug("Received path %s" % path)
+    # deal with ESRF external links with different names from the targets
+    correct_entry_path = False
+    entry_path = getEntryName(path)
+    entry_file = getEntryName(path, h5file=h5file)
+    _logger.debug("Associated entry name from path %s" % entry_path)
+    _logger.debug("Associated entry name from file %s" % entry_file)
+
+    if entry_path:
+        if entry_path != entry_file:
+            path = _correct_entry_path(path, entry_path, entry_file)
+            correct_entry_path = True
+    _logger.debug("Finally used path %s" % path)
+
     if ignore is None:
         ignore = ["channels",
                   "calibration",
@@ -279,7 +332,9 @@ def getMcaList(h5file, path, dataset=False, ignore=None):
                         if dataset:
                             datasetList.append(obj)
                         else:
-                            datasetList.append(obj.name)
+                            name = obj.name
+                            name = sanitizeFilePath(h5file, name)
+                            datasetList.append(name)
     if hasattr(h5file[path], "visititems"):
         # prevent errors dealing with toplevel datasets
         h5file[path].visititems(visit_function)
@@ -338,6 +393,16 @@ def getMcaObjectPaths(h5file, mcaPath):
     #mca["i0_to_flux_factor"] = 1.0
     #mca["it_to_flux_factor"] = 1.0
 
+    _logger.info("Input path <%s>" % (mcaPath,))
+
+    # check entry
+    entry_item = getEntryName(mcaPath)
+    entry_file = getEntryName(mcaPath, h5file=h5file)
+    if entry_item != entry_file:
+        mcaPath = _correct_entry_path(mcaPath, entry_item, entry_file)
+
+    _logger.info("Used path <%s>" % (mcaPath,))
+    
     # look at the same level as the dataset
     parentPath = posixpath.dirname(mcaPath)
     searchPaths =[parentPath]
@@ -364,7 +429,7 @@ def getMcaObjectPaths(h5file, mcaPath):
             baseKey = posixpath.basename(key)
             if (baseKey in mcaKeys) and (key != mcaPath):
                 if baseKey not in mca:
-                    mca[baseKey] = item.name
+                    mca[baseKey] = sanitizeFilePath(h5file, item.name)
 
     if len(mca) == 2:
         # we found nothing
@@ -393,10 +458,12 @@ def getNXClassGroups(h5file, path, classes, single=False):
     Retrieve the hdf5 groups inside a given path where the NX_class attribute
     matches one of the items in the classes list.
     """
+
     groups = []
     items_list = list(h5file[path].items())
     if ("NXentry" in classes) or (b"NXentry" in classes):
         items_list = h5py_sorting(items_list)
+
     for key, group in items_list:
         if not isGroup(group):
             continue
@@ -406,6 +473,10 @@ def getNXClassGroups(h5file, path, classes, single=False):
                     groups.append(group)
                     if single:
                         break
+        link = h5file.get(key, getlink=True)
+        if isinstance(link, h5py.ExternalLink):
+            _logger.info("External filename = <%s>" % link.filename)
+            _logger.info("External file path = <%s>" % link.path)
     return groups
 
 def getPositionersGroup(h5file, path):
@@ -419,7 +490,7 @@ def getPositionersGroup(h5file, path):
     - NXentry/measurement/pre_scan_snapshot
 
     """
-    entry_path = getEntryName(path)
+    entry_path = getEntryName(path, h5file=h5file)
     instrument = getNXClassGroups(h5file, entry_path, ["NXinstrument", b"NXinstrument"], single=True)
     positioners = None
     if len(instrument):
@@ -452,8 +523,9 @@ def getMeasurementGroup(h5file, path):
     """
     if path in ["/", b"/", "", b""]:
         raise ValueError("path cannot be the toplevel root")
-    entry_path = getEntryName(path)
+    entry_path = getEntryName(path, h5file=h5file)
     entry = h5file[entry_path]
+
     if hasattr(entry, "items"):
         items_list = entry.items()
     else:
@@ -493,7 +565,7 @@ def getMeasurementGroup(h5file, path):
     return measurement
 
 def getInstrumentGroup(h5file, path):
-    entry_name = getEntryName(path)
+    entry_name = getEntryName(path, h5file=h5file)
     groups = getNXClassGroups(h5file, entry_name, ["NXinstrument", b"NXinstrument"] , single=False)
     n = len(groups)
     if n == 0:
@@ -513,7 +585,7 @@ def getScannedPositioners(h5file, path):
         - Look for positioners with more than one single value
         - Look for datasets present at measurement and title
     """
-    entry_name = getEntryName(path)
+    entry_name = getEntryName(path, h5file=h5file)
     try:
         title = getTitle(h5file, path)
     except:
@@ -541,14 +613,14 @@ def getScannedPositioners(h5file, path):
                 scanned = [item.name for key, item in positioners.items() if \
                                             isDataset(item) and \
                                             (hasattr(item, "size") and (item.size > 1))]
-        if not len(scanned):
-            entry = h5file[entry_name]
-            if len(title) and hasattr(title, "split"):
+
+        if len(title) and hasattr(title, "split"):
+            if not len(scanned) or "fscan " in title:
                 tokens = title.split()
-                scanned = [item.name for key, item in measurement.items() if \
-                                            isDataset(item) and \
-                                            (key in tokens)]
-        
+                scanned = scanned + [item.name for key, item in measurement.items() if \
+                                                isDataset(item) and \
+                                                (key in tokens)]
+
         # provide proper sorting
         if len(scanned) > 1 and sys.version_info > (3, 3):
             # sort irrespective of capital or lower case
@@ -580,10 +652,10 @@ if __name__ == "__main__":
     except:
         h5 = h5py.File(sourcename, 'r')
     entries = getNXClassGroups(h5, "/", ["NXentry", b"NXentry"], single=False)
+    print("entries = ", entries)
     if not len(entries):
         entries = [item for name, item in h5["/"].items() if isGroup(item)]
     for entry in entries:
-        print("Entry name = %s" % entry.name)
         if "title" in entry:
             print("Entry title = %s" % entry["title"][()])
         measurement = getMeasurementGroup(h5, entry.name)
