@@ -34,7 +34,7 @@ _logger = logging.getLogger(__name__)
 
 from PyMca5.PyMcaGui import PyMcaQt as qt
 QTVERSION = qt.qVersion()
-from PyMca5.PyMcaGui import PyMca_Icons as icons
+from PyMca5.PyMcaGui.plotting import PyMca_Icons as icons
 from PyMca5.PyMcaIO import spswrap as sps
 from PyMca5 import PyMcaDirs
 from PyMca5.PyMcaGui.io import PyMcaFileDialogs
@@ -310,7 +310,7 @@ class QSourceSelector(qt.QWidget):
             else:
                 menu.addAction(session,
                         lambda i=session:self.openFile(i, specsession="bliss"))
-        menu.exec_(self.cursor().pos())
+        menu.exec(self.cursor().pos())
         
 
     def openSpec(self):
@@ -329,7 +329,7 @@ class QSourceSelector(qt.QWidget):
             else:
                 menu.addAction(spec,
                         lambda i=spec:self.openFile(i, specsession=True))
-        menu.exec_(self.cursor().pos())
+        menu.exec(self.cursor().pos())
 
 
     def _fileSelection(self, qstring):
