@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,19 +23,19 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
 
 import numpy
 from PyMca5.PyMcaGui import PyMcaQt as qt
-from PyMca5.PyMcaGui import PyMca_Icons
+from PyMca5.PyMcaGui.plotting import PyMca_Icons
 IconDict = PyMca_Icons.IconDict
-from PyMca5.PyMcaGui import MaskImageWidget
-from PyMca5.PyMcaGui import ScanWindow
+from PyMca5.PyMcaGui.plotting import MaskImageWidget
+from PyMca5.PyMcaGui.pymca import ScanWindow
 from PyMca5.PyMcaMath.mva import PCAModule
-from PyMca5.PyMcaGui import ScatterPlotCorrelatorWidget
+from PyMca5.PyMcaGui.plotting import ScatterPlotCorrelatorWidget
 
 if hasattr(qt, "QString"):
     QString = qt.QString
