@@ -34,7 +34,7 @@ import logging
 from PyMca5.PyMcaCore import EventHandler
 from PyMca5.PyMcaMath.fitting import Specfit
 from PyMca5.PyMcaGui import PyMcaQt as qt
-from PyMca5.PyMcaGui import PyMcaFileDialogs
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 
 QTVERSION = qt.qVersion()
 from . import FitConfigGui
@@ -94,8 +94,8 @@ class SpecfitGui(qt.QWidget):
             self.guiconfig.FunComBox.textActivated[str].connect(self.funevent)
         else:
             self.guiconfig.BkgComBox.activated[str].connect(self.bkgevent)
-            self.guiconfig.FunComBox.activated[str].connect(self.funevent)            
-            layout.addWidget(self.guiconfig)
+            self.guiconfig.FunComBox.activated[str].connect(self.funevent)
+        layout.addWidget(self.guiconfig)
 
         self.guiparameters = MultiParameters.ParametersTab(self)
         layout.addWidget(self.guiparameters)
