@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2021 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -648,7 +648,7 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
                                        self._setBrush5)
             self._brushMenu.addAction(QString("20 Image Pixel Width"),
                                        self._setBrush6)
-        self._brushMenu.exec_(self.cursor().pos())
+        self._brushMenu.exec(self.cursor().pos())
 
     def _brushSelectionIconSignal(self):
         _logger.debug("_setBrushSelectionMode")
@@ -782,9 +782,9 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
 
     def _additionalIconSignal(self):
         if self._plotViewMode == "density": # and imageData is not none ...
-            self._additionalSelectionMenu["density"].exec_(self.cursor().pos())
+            self._additionalSelectionMenu["density"].exec(self.cursor().pos())
         else:
-            self._additionalSelectionMenu["scatter"].exec_(self.cursor().pos())
+            self._additionalSelectionMenu["scatter"].exec(self.cursor().pos())
 
     def __resetSelection(self):
         # Needed because receiving directly in _resetSelection it was passing
