@@ -190,9 +190,9 @@ class PlotWindow(PlotWidget.PlotWidget):
                                        self.toggleCrosshairCursor)
             controlMenu.addAction(QString("Toggle Arrow Keys Panning"),
                                        self.toggleArrowKeysPanning)
-            controlMenu.exec_(self.cursor().pos())
+            controlMenu.exec(self.cursor().pos())
         else:
-            self._controlMenu.exec_(self.cursor().pos())
+            self._controlMenu.exec(self.cursor().pos())
 
     def setControlMenu(self, menu=None):
         self._controlMenu = menu
@@ -483,9 +483,9 @@ class PlotWindow(PlotWidget.PlotWidget):
                             self._getPrintConfigurationFromDialog)
             printMenu.addAction(QString("Print"),
                                        self.printGraph)
-            printMenu.exec_(self.cursor().pos())
+            printMenu.exec(self.cursor().pos())
         else:
-            self._printMenu.exec_(self.cursor().pos())
+            self._printMenu.exec(self.cursor().pos())
 
     def printGraph(self, *var, **kw):
         config = self.getPrintConfiguration()
@@ -949,12 +949,16 @@ class PlotWindow(PlotWidget.PlotWidget):
                 if tip is not None:
                     action.setToolTip(tip)
                 menu.addAction(action)
+            elif self.pluginInstanceDict[m].__doc__:
+                action = qt.QAction(text, self)
+                action.setToolTip(self.pluginInstanceDict[m].__doc__)
+                menu.addAction(action)
             else:
                 menu.addAction(text)
             actionList.append(text)
             callableKeys.append(m)
         menu.hovered.connect(self._actionHovered)
-        a = menu.exec_(qt.QCursor.pos())
+        a = menu.exec(qt.QCursor.pos())
         if a is None:
             return None
         idx = actionList.index(a.text())
@@ -1006,7 +1010,7 @@ class PlotWindow(PlotWidget.PlotWidget):
                 actionList.append((text, pixmap, tip, action))
             #qt.QObject.connect(menu, qt.SIGNAL("hovered(QAction *)"), self._actionHovered)
             menu.hovered.connect(self._actionHovered)
-            a = menu.exec_(qt.QCursor.pos())
+            a = menu.exec(qt.QCursor.pos())
             if a is None:
                 return None
             idx = -1
