@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2019 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -108,9 +108,12 @@ class PyMcaPrintPreview(qt.QDialog):
         self.badNews = None
 
     def exec_(self):
+        return self.exec()
+
+    def exec(self):
         if self._toBeCleared:
             self.__clearAll()
-        return qt.QDialog.exec_(self)
+        return qt.QDialog.exec(self)
 
     def raise_(self):
         if self._toBeCleared:
