@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2016 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -109,7 +109,7 @@ class RGBCorrelatorGraph(qt.QWidget):
         self.mainLayout.addWidget(self.graph)
 
     def sizeHint(self):
-        return qt.QSize(1.5 * qt.QWidget.sizeHint(self).width(),
+        return qt.QSize(int(1.5 * qt.QWidget.sizeHint(self).width()),
                         qt.QWidget.sizeHint(self).height())
 
     def _buildToolBar(self, selection=False, colormap=False,
