@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -46,7 +46,7 @@ if __name__ == "__main__":
 import copy
 
 from PyMca5.PyMcaGui.io import PyMcaFileDialogs
-from PyMca5.PyMcaGui import IconDict
+from PyMca5.PyMcaGui.plotting.PyMca_Icons import IconDict
 from .ScanWindow import ScanWindow
 from . import McaCalibrationControlGUI
 from PyMca5.PyMcaIO import ConfigDict
@@ -56,10 +56,10 @@ from PyMca5.PyMcaCore import DataObject
 from . import McaSimpleFit
 from PyMca5.PyMcaMath.fitting import Specfit
 from PyMca5.PyMcaMath.fitting import SpecfitFuns
-from PyMca5.PyMcaGui import PyMcaPrintPreview
+from PyMca5.PyMcaGui.plotting import PyMcaPrintPreview
 from PyMca5 import PyMcaDirs
 
-from PyMca5.PyMcaGui import QPyMcaMatplotlibSave1D
+from PyMca5.PyMcaGui.pymca import QPyMcaMatplotlibSave1D
 MATPLOTLIB = True
 
 # force understanding of utf-8 encoding
@@ -436,7 +436,7 @@ class McaWindow(ScanWindow):
                         if 'McaCalibSource' in curveinfo:
                             key = "%s (Source)" % curve
                             if key not in ndict:
-                                if curveinfo['McaCalibSource'] != [0.0,1.0,0.0]:
+                                if not numpy.alltrue(curveinfo['McaCalibSource'] == [0.0,1.0,0.0]):
                                     ndict[key] = {'A':curveinfo['McaCalibSource'][0],
                                                   'B':curveinfo['McaCalibSource'][1],
                                                   'C':curveinfo['McaCalibSource'][2]}
@@ -445,8 +445,8 @@ class McaWindow(ScanWindow):
                                     else:
                                         ndict[key]['order'] = 1
                             if curve not in self.caldict.keys():
-                                if curveinfo['McaCalib'] != [0.0,1.0,0.0]:
-                                    if curveinfo['McaCalib'] != curveinfo['McaCalibSource']:
+                                if not numpy.alltrue(curveinfo['McaCalib'] == [0.0,1.0,0.0]):
+                                    if not numpy.alltrue(curveinfo['McaCalib'] == curveinfo['McaCalibSource']):
                                         key = "%s (PyMca)" % curve
                                         ndict[key] = {'A':curveinfo['McaCalib'][0],
                                                       'B':curveinfo['McaCalib'][1],
@@ -457,7 +457,7 @@ class McaWindow(ScanWindow):
                                             ndict[key]['order'] = 1
                         else:
                             if curve not in self.caldict.keys():
-                                if curveinfo['McaCalib'] != [0.0,1.0,0.0]:
+                                if not numpy.alltrue(curveinfo['McaCalib'] == [0.0,1.0,0.0]):
                                         key = "%s (PyMca)" % curve
                                         ndict[key] = {'A':curveinfo['McaCalib'][0],
                                                       'B':curveinfo['McaCalib'][1],
