@@ -260,27 +260,27 @@ if sys.platform.startswith("linux"):
             OBJECT3D = False
             _logger.warning("OpenGL disabled. Errors using glxinfo command")
 
-if OPENGL_DRIVERS_OK and isSilxGLAvailable:
-    # additional test (takes care of disabled forwarding)
-    try:
-        from silx.gui.utils.glutils import isOpenGLAvailable
-        isSilxGLAvailable = isOpenGLAvailable(version=(2, 1), runtimeCheck=True)
-        if not isSilxGLAvailable:
-            _logger.info("OpenGL >= 2.1 not available")
-            if not isOpenGLAvailable(version=(1, 4), runtimeCheck=True):
-                _logger.info("OpenGL >= 1.4 not available")
-                OPENGL_DRIVERS_OK = False
-                OBJECT3D = False
-    except:
-        _logger.info("Cannot test OpenGL availability %s" % sys.exc_info()[1])
+    if OPENGL_DRIVERS_OK and isSilxGLAvailable:
+        # additional test (takes care of disabled forwarding)
+        try:
+            from silx.gui.utils.glutils import isOpenGLAvailable
+            isSilxGLAvailable = isOpenGLAvailable(version=(2, 1), runtimeCheck=True)
+            if not isSilxGLAvailable:
+                _logger.info("OpenGL >= 2.1 not available")
+                if not isOpenGLAvailable(version=(1, 4), runtimeCheck=True):
+                    _logger.info("OpenGL >= 1.4 not available")
+                    OPENGL_DRIVERS_OK = False
+                    OBJECT3D = False
+        except:
+            _logger.info("Cannot test OpenGL availability %s" % sys.exc_info()[1])
 
 # PyMca 3D disabled in favor of silx
 OBJECT3D = isSilxGLAvailable
 _logger.info("SilxGL availability: %s", isSilxGLAvailable)
 
 from PyMca5.PyMcaGui.pymca import QDispatcher
-from PyMca5.PyMcaGui import ElementsInfo
-from PyMca5.PyMcaGui import PeakIdentifier
+from PyMca5.PyMcaGui.physics.xrf import ElementsInfo
+from PyMca5.PyMcaGui.physics.xrf import PeakIdentifier
 from PyMca5.PyMcaGui.pymca import PyMcaBatch
 ###########import Fit2Spec
 from PyMca5.PyMcaGui.pymca import Mca2Edf
@@ -291,8 +291,8 @@ try:
 except:
     STACK = False
 from PyMca5.PyMcaGui.pymca import PyMcaPostBatch
-from PyMca5.PyMcaGui import RGBCorrelator
-from PyMca5.PyMcaGui import MaterialEditor
+from PyMca5.PyMcaGui.pymca import RGBCorrelator
+from PyMca5.PyMcaGui.physics.xrf import MaterialEditor
 
 from PyMca5.PyMcaIO import ConfigDict
 from PyMca5 import PyMcaDirs
@@ -1006,7 +1006,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                                               **d['Information'])
                 if d['LastFit']['hidden'] == 'False':
                     self.mcaWindow.advancedfit.show()
-                    self.mcaWindow.advancedfit.raiseW()
+                    self.mcaWindow.advancedfit.raise_()
                     if d['LastFit']['fitdone']:
                         try:
                             self.mcaWindow.advancedfit.fit()
@@ -1031,7 +1031,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                                               **d['Information'])
                 if d['LastFit']['hidden'] == 'False':
                     self.mcaWindow.advancedfit.show()
-                    self.mcaWindow.advancedfit.raiseW()
+                    self.mcaWindow.advancedfit.raise_()
                     if d['LastFit']['fitdone']:
                         try:
                             self.mcaWindow.advancedfit.fit()
@@ -1510,7 +1510,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         self._sumRulesTool.raise_()
 
     def onOpen(self):
-        self.openMenu.exec_(self.cursor().pos())
+        self.openMenu.exec(self.cursor().pos())
 
     def onSave(self):
         self._saveAs()
@@ -1529,7 +1529,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         elif text in self.imageWindowDict.keys():
             self.saveMenu.addAction("Active Image",
                   self.imageWindowDict[text].graphWidget._saveIconSignal)
-        self.saveMenu.exec_(self.cursor().pos())
+        self.saveMenu.exec(self.cursor().pos())
 
     def _onSaveAs(self):
         cwd = os.getcwd()
@@ -1610,7 +1610,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 self.trainingDataMenu.addAction(action)
         try:
             source = None
-            selectedAction = self.trainingDataMenu.exec_(qt.QCursor.pos())
+            selectedAction = self.trainingDataMenu.exec(qt.QCursor.pos())
             if selectedAction is not None:
                 key = qt.safe_str(selectedAction.text())
                 source = self.trainingSources[key]
@@ -1854,8 +1854,9 @@ class MyQTextBrowser(qt.QTextBrowser):
                 self.report.mimeSourceFactory().addFilePath(QString(ddir+"/HTML"))
                 self.report.mimeSourceFactory().addFilePath(QString(ddir+"/HTML/PyMCA_files"))
                 self.report.setSource(name)
-            if self.report.isHidden():self.report.show()
-            self.report.raiseW()
+            if self.report.isHidden():
+                self.report.show()
+            self.report.raise_()
         else:
             qt.QTextBrowser.setSource(self, name)
 
