@@ -30,6 +30,7 @@ __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
 import sys
 import os
+import copy
 import traceback
 import numpy
 import weakref
@@ -289,6 +290,11 @@ class QStackWidget(StackBase.StackBase,
                 self.stackWidget.setImageData(None)
                 self.roiWidget.setImageData(None)
                 StackBase.StackBase.setStack(self, self._stack, **kw)
+        if self._mcaMax is not None:
+            self.addMcaMaxButton.show()
+        else:
+            self.addMcaMaxButton.hide()
+
         try:
             if 'SourceName' in self._stack.info:
                 if type(self._stack.info['SourceName']) == type([]):
@@ -461,6 +467,9 @@ class QStackWidget(StackBase.StackBase,
         return view
 
     def exportStackList(self, filename=None):
+        if not self.master:
+            raise IOError("Only primary stacks can export all stacks")
+
         if filename is None:
             filename = self._getOutputHDF5Filename()
             if not len(filename):
@@ -469,7 +478,17 @@ class QStackWidget(StackBase.StackBase,
             # delete an existing file
             if os.path.exists(filename):
                 os.remove(filename)
-        McaStackExport.exportStackList(self.getStackDataObjectList(), filename)
+
+        calibrationList = []
+        # master, join all slaves
+        calibrationList.append(self.getActiveCurveCalibration())
+        if self._slaveList is not None:
+            for slave in self._slaveList:
+                calibrationList.append(slave.getActiveCurveCalibration())
+                
+        McaStackExport.exportStackList(self.getStackDataObjectList(),
+                                       filename,
+                                       calibration=calibrationList)
 
     def exportStack(self, filename=None):
         if filename is None:
@@ -480,7 +499,25 @@ class QStackWidget(StackBase.StackBase,
             # delete an existing file
             if os.path.exists(filename):
                 os.remove(filename)
-        McaStackExport.exportStackList([self.getStackDataObject()], filename)
+
+        # try to get the current calibration, not the one loaded
+        calibration = self.getActiveCurveCalibration()
+
+        # save the stack
+        McaStackExport.exportStackList([self.getStackDataObject()],
+                                       filename,
+                                       calibration=[calibration])
+
+    def getActiveCurveCalibration(self):
+        calibration = None
+        try:
+            xLabel = qt.safe_str(self.getGraphXLabel())
+            xData, y, legend, info = self.mcaWidget.getActiveCurve()[:4]
+            if xLabel not in [None, 'Channels']:
+                calibration = info.get("McaCalib", None)
+        except:
+            _logger.info("Cannot obtain current calibration")
+        return calibration
 
     def saveStackAsNeXus(self, dtype=None, interpretation=None, compression=False):
         mcaIndex = self._stack.info.get('McaIndex', -1)
@@ -502,7 +539,7 @@ class QStackWidget(StackBase.StackBase,
         axes = [None] * len(self._stack.data.shape)
         labels = [None] * len(self._stack.data.shape)
         try:
-            xLabel = qt.safe_str(self.mcaWidget.graph.getGraphXLabel())
+            xLabel = qt.safe_str(self.mcaWidget.getGraphXLabel())
         except:
             xLabel = None
         try:
@@ -809,9 +846,16 @@ class QStackWidget(StackBase.StackBase,
                 callableKeys.append(m)
         additionalItems.sort()
         for text, m in additionalItems:
-            menu.addAction(text)
+            if self.pluginInstanceDict[m].__doc__:
+                tip = self.pluginInstanceDict[m].__doc__
+                action = qt.QAction(text, self)
+                action.setToolTip(tip)
+                menu.addAction(action)
+            else:
+                menu.addAction(text)
             actionList.append(text)
             callableKeys.append(m)
+        menu.hovered.connect(self._actionHovered)
         a = menu.exec(qt.QCursor.pos())
         if a is None:
             return None
@@ -887,9 +931,14 @@ class QStackWidget(StackBase.StackBase,
 
     def _actionHovered(self, action):
         tip = action.toolTip()
-        if qt.safe_str(tip) != qt.safe_str(action.text()):
+        if str(tip) != str(action.text()):
             qt.QToolTip.showText(qt.QCursor.pos(), tip)
-
+        else:
+            # hideText was introduced in Qt 4.2
+            if hasattr(qt.QToolTip, "hideText"):
+                qt.QToolTip.hideText()
+            else:
+                qt.QToolTip.showText(qt.QCursor.pos(), "")
 
     def _buildBottom(self):
         n = 0
@@ -928,17 +977,23 @@ class QStackWidget(StackBase.StackBase,
         self.mcaButtonBoxLayout.setSpacing(0)
         self.addMcaButton = qt.QPushButton(self.mcaButtonBox)
         self.addMcaButton.setText("ADD MCA")
+        self.addMcaMaxButton = qt.QPushButton(self.mcaButtonBox)
+        self.addMcaMaxButton.setText("ADD MCA MAX")
+        self.addMcaMaxButton.setToolTip('Add spectrum of the maximum at each channel.')
         self.removeMcaButton = qt.QPushButton(self.mcaButtonBox)
         self.removeMcaButton.setText("REMOVE MCA")
         self.replaceMcaButton = qt.QPushButton(self.mcaButtonBox)
         self.replaceMcaButton.setText("REPLACE MCA")
         self.mcaButtonBoxLayout.addWidget(self.addMcaButton)
+        self.mcaButtonBoxLayout.addWidget(self.addMcaMaxButton)
         self.mcaButtonBoxLayout.addWidget(self.removeMcaButton)
         self.mcaButtonBoxLayout.addWidget(self.replaceMcaButton)
+        self.addMcaMaxButton.hide()
 
         self.stackWindow.mainLayout.addWidget(self.mcaButtonBox)
 
         self.addMcaButton.clicked.connect(self.__addMcaClicked)
+        self.addMcaMaxButton.clicked.connect(self._addMcaMaxClicked)
         self.removeMcaButton.clicked.connect(self._removeMcaClicked)
         self.replaceMcaButton.clicked.connect(self._replaceMcaClicked)
 
@@ -1079,6 +1134,17 @@ class QStackWidget(StackBase.StackBase,
     def __addMcaClicked(self):
         self._addMcaClicked("ADD")
 
+    def _addMcaMaxClicked(self):
+        if self._mcaMax is not None:
+            dataObject = copy.deepcopy(self._mcaData0)
+            dataObject.y = [self._mcaMax]
+            self.sendMcaSelection(dataObject,
+                                  key="Maximum",
+                                  legend= "Max Spectrum",
+                                  action="ADD")
+        else:
+            self.addMcaMaxButton.hide()
+
     def _addMcaClicked(self, action=None):
         if action in [None, False]:
             action = "ADD"
@@ -1289,8 +1355,38 @@ class QStackWidget(StackBase.StackBase,
             selectionMask = numpy.zeros(self._stackImageData.shape,
                                      numpy.uint8)
             selectionMask[row, column] = 1
-            dataObject = self.calculateMcaDataObject(normalize=True,
+            dataObject = self.calculateMcaDataObject(normalize=False,
                                                      mask=selectionMask)
+            mcaIndex = self._stack.info.get('McaIndex', -1)
+            if mcaIndex in [-1, len(self._stack.data.shape) - 1]:
+                try:
+                    positioners = self._stack.info.get("positioners", None)
+                    if positioners:
+                        def _to_index_mode(slice_idx, shape):
+                            if len(shape) == 2:
+                                return slice_idx[0]
+                            single_index = 0
+                            for i in range(len(slice_idx)):
+                                v = 1
+                                for j in range(i+1, len(shape) - 1): 
+                                    v *= shape[j]
+                                single_index += v * slice_idx[i]
+                            return single_index
+                        idx = _to_index_mode((row, column),
+                                             self._stack.data.shape)
+                        motorNames = []
+                        motorValues = []
+                        for key, value in positioners.items():
+                            motorNames.append(key)
+                            if hasattr(value, "__len__"):
+                                motorValues.append(value[idx])
+                            else:
+                                motorValues.append(value)
+                        dataObject.info["MotorNames"] = motorNames
+                        dataObject.info["MotorValues"] = motorValues
+                except:
+                    _logger.warning("Error obtaining positioners")
+
             self.sendMcaSelection(dataObject,
                                      key="Selection",
                                      legend="MCA[%d,%d]" % (row, column),
