@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -37,11 +37,11 @@ if hasattr(qt, 'QString'):
     QString = qt.QString
 else:
     QString = str
-from PyMca5.PyMcaGui import RGBCorrelatorGraph
-from PyMca5.PyMcaGui import QPyMcaMatplotlibSave
+from PyMca5.PyMcaGui.plotting import RGBCorrelatorGraph
+from PyMca5.PyMcaGui.pymca import QPyMcaMatplotlibSave
 USE_MASK_WIDGET = False
 if USE_MASK_WIDGET:
-    from PyMca5.PyMcaGui import MaskImageWidget
+    from PyMca5.PyMcaGui.plotting import MaskImageWidget
     
 MATPLOTLIB = True
 
@@ -138,7 +138,7 @@ class RGBCorrelator(qt.QWidget):
             self.graph.replot()
 
     def _saveToolButtonSignal(self):
-        self._saveMenu.exec_(self.cursor().pos())
+        self._saveMenu.exec(self.cursor().pos())
 
     def _saveMatplotlibImage(self):
         if self._matplotlibSaveImage is None:
