@@ -264,7 +264,7 @@ class RGBImageCalculator(qt.QWidget):
         nSamples = image.size
         # build a stack (expected a small amount of images)
         data = numpy.zeros((nSamples, len(keys)),
-                            dtype=numpy.float)
+                            dtype=numpy.float64)
         i = 0
         for key in self.imageDict:
             data[:, i] = self.imageDict[key]['image'].ravel()
@@ -282,7 +282,7 @@ class RGBImageCalculator(qt.QWidget):
             msg.setText(text)
             msg.setInformativeText(qt.safe_str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
             return 1
         self.setName("(%s)" % name)
         self.plotImage()
@@ -374,7 +374,7 @@ def test():
     w.imageList = imageList
     w.imageDict = imageDict
     w.show()
-    app.exec_()
+    app.exec()
 
 if __name__ == "__main__":
     test()
