@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -281,7 +281,7 @@ class StackPluginResultsWindow(MaskImageWidget.MaskImageWidget):
 
     def _spectrumGraphIconSlot(self, ddict):
         if ddict["event"] == "iconClicked" and ddict["key"] == "save":
-            self.spectrumGraph.saveMenu.exec_(qt.QCursor.pos())
+            self.spectrumGraph.saveMenu.exec(qt.QCursor.pos())
 
     def saveCurrentSpectrum(self):
         return self.spectrumGraph._QSimpleOperation("save")
@@ -376,7 +376,7 @@ def test():
         print(ddict['event'])
 
     container.sigMaskImageWidgetSignal.connect(theSlot)
-    app.exec_()
+    app.exec()
 
 if __name__ == "__main__":
     import numpy
