@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -51,6 +51,8 @@ from PyMca5.PyMcaIO import RenishawMap
 from PyMca5.PyMcaIO import OmdaqLmf
 from PyMca5.PyMcaIO import JcampOpusStack
 from PyMca5.PyMcaIO import FsmMap
+from PyMca5.PyMcaIO import LabSpec6TxtMap
+from PyMca5.PyMcaIO import BrukerBCF
 from .QStack import QStack, QSpecFileStack
 try:
     from PyMca5.PyMcaGui.pymca import QHDF5Stack1D
@@ -119,6 +121,18 @@ class StackSelector(object):
                 imagestack = True
                 fileindex = 0
                 stack = TextImageStack.TextImageStack(imagestack=True)
+            elif filefilter.upper().startswith("LABSPEC6") and\
+                 (filelist[0].upper().endswith("TIF") or\
+                  filelist[0].upper().endswith("TIFF")):
+                stack = TiffStack.TiffStack(imagestack=True)
+                stack.loadFileList(filelist[0])
+                stack.info["FileIndex"] = 0
+                stack.info["McaIndex"] = 2
+                omnicfile = True
+            elif filefilter.upper().startswith("LABSPEC6") and\
+                 filelist[0].upper().endswith("TXT"):
+                stack = LabSpec6TxtMap.LabSpec6TxtMap(filelist[0])
+                omnicfile = True
             elif filefilter.upper().startswith("IMAGE") and\
                  (filelist[0].upper().endswith("TIF") or\
                   filelist[0].upper().endswith("TIFF")):
@@ -189,17 +203,25 @@ class StackSelector(object):
                 # columns would be accepted as a Renishaw Map
                 # by other hand, I do not know how to handle
                 # that case as a stack.
+                _logger.info("RenishawMap")
                 stack = RenishawMap.RenishawMap(filelist[0])
                 omnicfile = True
             elif OmdaqLmf.isOmdaqLmf(filelist[0]):
+                _logger.info("OmdaqLmf")
                 stack = OmdaqLmf.OmdaqLmf(filelist[0])
                 omnicfile = True
             elif FsmMap.isFsmFile(filelist[0]):
+                _logger.info("FsmMap")
                 stack = FsmMap.FsmMap(filelist[0])
                 omnicfile = True
             elif JcampOpusStack.isJcampOpusStackFile(filelist[0]):
+                _logger.info("JcampOpusStack")
                 stack = JcampOpusStack.JcampOpusStack(filelist[0])
                 omnicfile = True
+            elif BrukerBCF.isBrukerBCFFile(filelist[0]):
+                _logger.info("Bruker bcf")
+                stack = BrukerBCF.BrukerBCF(filelist[0])
+                omnicfile = True
             else:
                 stack = QSpecFileStack()
 
@@ -361,17 +383,18 @@ class StackSelector(object):
     def _getStackOfFiles(self, getfilter=None):
         if getfilter is None:
             getfilter = False
-        fileTypeList = ["EDF Files (*edf *edf.gz)",
+        fileTypeList = ["HDF5 Files (*.nxs *.hdf *.hdf5 *.h5)",
+                        "EDF Files (*edf *edf.gz)",
+                        "EDF Files (*ccd)",
                         "Image Files (*edf *ccd *raw *edf.gz *ccd.gz *raw.gz *cbf)",
                         "Image Files (*tif *tiff *TIF *TIFF)",
                         "TextImage Files (*txt)",
-                        "HDF5 Files (*.nxs *.hdf *.hdf5 *.h5)",
-                        "EDF Files (*ccd)",
                         "Specfile Files (*mca)",
                         "Specfile Files (*dat)",
                         "OMNIC Files (*map)",
                         "OPUS-DPT Files (*.DPT *.dpt)",
                         "JCAMP-DX Files (*.JDX *.jdx *.DX *.dx)",
+                        "LabSpec6 Files (*.tif *.TIF *.TIFF *.TIFF *.txt *.TXT)",
                         "RTX Files (*.rtx *.RTX)",
                         "Lispix-RPL Files (*.rpl)",
                         "Renishaw-ASCII Files (*.txt *.TXT)",
@@ -383,6 +406,9 @@ class StackSelector(object):
         if not HDF5:
             idx = fileTypeList.index("HDF5 Files (*.nxs *.hdf *.hdf5 *.h5)")
             del fileTypeList[idx]
+        if BrukerBCF.HAS_BCF_SUPPORT:
+            idx = fileTypeList.index("RTX Files (*.rtx *.RTX)")
+            fileTypeList.insert(idx+1, "BCF Files (*.bcf *.BCF)")
         message = "Open ONE indexed stack or SEVERAL files"
         return self._getFileList(fileTypeList, message=message,
                                  getfilter=getfilter)
