@@ -1,5 +1,5 @@
 # /*##########################################################################
-# Copyright (C) 1995-2020 European Synchrotron Radiation Facility
+# Copyright (C) 1995-2022 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -82,6 +82,9 @@ DllExport double SfMotorPosByName( SpecFile *sf, long index, char *name,
 DllExport long   SfAllMotorPos   ( SpecFile *sf, long index, double **pos,
                                       int *error );
 
+#define BUFFER_SIZE 256
+#define MIN(a, b) (((a) <= (b)) ? (a) : (b))
+
 
 /*********************************************************************
  *   Function:		char *SfLabel( sf, index, column, error )
@@ -175,7 +178,7 @@ SfLabel( SpecFile *sf, long index, long column, int *error )
 DllExport long
 SfAllLabels( SpecFile *sf, long index, char ***labels, int *error )
 {
-     static char tmplab[40];
+     static char tmplab[BUFFER_SIZE];
 
      char **labarr;
      char  *onelabel;
@@ -238,7 +241,7 @@ SfAllLabels( SpecFile *sf, long index, char ***labels, int *error )
 
      for (i=0;ptr < buf + strlen(buf) -1;ptr++,i++) {
          if (*ptr==' ' && *(ptr+1) == ' ') { /* two spaces delimits one label */
-             tmplab[i] = '\0';
+             tmplab[MIN(i, BUFFER_SIZE-1)] = '\0';
 
              labarr = (char **)realloc( labarr, (no_labels+1) * sizeof(char *));
              onelabel = (char *) malloc (i+2);
@@ -248,7 +251,7 @@ SfAllLabels( SpecFile *sf, long index, char ***labels, int *error )
              no_labels++;
              i=-1;
              for(;*(ptr+1) == ' ' && ptr < buf+strlen(buf)-1;ptr++);
-         } else {
+         } else if (i < BUFFER_SIZE){
              tmplab[i] = *ptr;
          }
      }
@@ -313,7 +316,7 @@ SfAllMotors( SpecFile *sf, long index, char ***names, int *error )
      char **motarr;
      char  *onemot;
 
-     static char tmpmot[40];
+     static char tmpmot[BUFFER_SIZE];
 
      char  *ptr;
 
@@ -363,7 +366,7 @@ SfAllMotors( SpecFile *sf, long index, char ***names, int *error )
          for(ptr=thisline;*ptr == ' ';ptr++);
          for (i=0;ptr < endline -2;ptr++,i++) {
             if (*ptr==' ' && *(ptr+1) == ' ') {
-               tmpmot[i] = '\0';
+               tmpmot[MIN(i, BUFFER_SIZE-1)] = '\0';
 
                motarr = (char **)realloc( motarr, (motct+1) * sizeof(char *));
                onemot = (char *) malloc (i+2);
@@ -373,7 +376,7 @@ SfAllMotors( SpecFile *sf, long index, char ***names, int *error )
                motct++;
                i=-1;
                for(;*(ptr+1) == ' ' && ptr < endline -1;ptr++);
-            } else {
+            } else if (i < BUFFER_SIZE) {
                tmpmot[i] = *ptr;
             }
         }
