@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -206,7 +206,7 @@ class FastXRFLinearFit(object):
             if outbuffer.saveDataDiagnostics:
                 derivAttrs = {}
                 derivAttrs['axes'] = [('energy', xenergy.astype(dtypeResult), {'units': 'keV'}),
-                                      ('channels', xdata.astype(numpy.int32), {})]
+                                      ('channels', xdata.astype(numpy.float32), {})]
                 derivAttrs['axesused'] = ["energy"]
                 _derivatives = outbuffer.allocateMemory('derivatives',
                                         shape=(nFree, xdata.size),
